@@ -1,11 +1,11 @@
 /*
-   %W%, %I% %E% %U%
+   engn/perldb2/dbdimp.h, engn_perldb2, db2_v82fp9, 1.11 04/09/13 17:27:00
 
-   Copyright (c) 1995,1996,1997,1998,1999,2000 International Business Machines Corp.
+   Copyright (c) 1995-2004 International Business Machines Corp.
 */
 
 /* these are (almost) random values ! */
-#define MAX_COL_NAME_LEN 128
+#define MAX_COL_NAME_LEN 128                                      
 #define MAX_BIND_VARS   99
 
 
@@ -15,7 +15,7 @@ struct imp_drh_st {
   dbih_drc_t com;                     /* MUST be first element in structure   */
   SQLHENV henv;
   int     connects;
-  SV     *svNUM_OF_FIELDS;
+  SV     *svNUM_OF_FIELDS;                                       
 };
 
 /* Define dbh implementor data structure */
@@ -23,7 +23,7 @@ struct imp_dbh_st {
   dbih_dbc_t com;                     /* MUST be first element in structure   */
   SQLHENV henv;
   SQLHDBC hdbc;
-  char sqlerrp[9];
+  char sqlerrp[9];                                               
 };
 
 
@@ -60,13 +60,13 @@ struct imp_fbh_st {     /* field buffer */
   imp_sth_t *imp_sth; /* 'parent' statement */
 
   /* description of the field */
-  SQLSMALLINT dbtype;
+  SQLSMALLINT dbtype;                                            
   SQLCHAR    *cbuf;           /* ptr to name of select-list item */
   SQLSMALLINT cbufl;          /* length of select-list item name */
   SQLINTEGER  dsize;          /* max display size if field is a SQLCHAR */
-  SQLUINTEGER prec;
-  SQLSMALLINT scale;
-  SQLSMALLINT nullok;
+  SQLUINTEGER prec;                                              
+  SQLSMALLINT scale;                                             
+  SQLSMALLINT nullok;                                            
 
   /* Our storage space for the field data as it's fetched */
   SQLSMALLINT ftype;          /* external datatype we wish to get             */
@@ -87,20 +87,18 @@ struct phs_st { /* scalar placeholder */
   SQLINTEGER   indp;                /* null indicator or length indicator     */
   int          bDescribed;          /* already described this parameter       */
   int          bDescribeOK;         /* describe was successful                */
-  SQLSMALLINT  descSQLType;
-  SQLSMALLINT  descDecimalDigits;
-  SQLUINTEGER  descColumnSize;
+  SQLSMALLINT  descSQLType;                                      
+  SQLSMALLINT  descDecimalDigits;                                
+  SQLUINTEGER  descColumnSize;                                   
 };
 
-SQLCHAR sql_state[6];
-
 #define dbd_init            db2_init
 #ifndef AS400
-#define dbd_data_sources    db2_data_sources
+#define dbd_data_sources    db2_data_sources                     
 #endif
 #define dbd_db_login        db2_db_login
 #define dbd_db_do           db2_db_do
-#define dbd_db_ping         db2_db_ping
+#define dbd_db_ping         db2_db_ping                          
 #define dbd_db_commit       db2_db_commit
 #define dbd_db_rollback     db2_db_rollback
 #define dbd_db_disconnect   db2_db_disconnect
@@ -114,10 +112,17 @@ SQLCHAR sql_state[6];
 #define dbd_st_fetch        db2_st_fetch
 #define dbd_st_finish       db2_st_finish
 #define dbd_st_destroy      db2_st_destroy
-#define dbd_st_blob_read    db2_st_blob_read
+#define dbd_st_blob_read    db2_st_blob_read                     
 #define dbd_st_STORE_attrib db2_st_STORE_attrib
 #define dbd_st_FETCH_attrib db2_st_FETCH_attrib
 #define dbd_describe        db2_describe
 #define dbd_bind_ph         db2_bind_ph
 
+#define dbd_st_primary_key_info db2_st_primary_key_info          
+#define dbd_st_foreign_key_info db2_st_foreign_key_info          
+#define dbd_st_type_info_all    db2_st_type_info_all             
+#define dbd_st_column_info      db2_st_column_info               
+#define dbd_db_get_info         db2_db_get_info                  
+
+
 /* end */
